@@ -31,7 +31,13 @@ sub initialize_db {
 
   # Get the base workflow directory.
   my $workflow_base = cwd();
-  $workflow_base =~ s/\A(.*)\/t/$1/;
+  
+  #we are called from the examples directory
+  if ($workflow_base =~ m[/eg/ticket]) {
+    $workflow_base =~ s/\A(.*)\/eg\/ticket/$1/;
+  } else {
+    $workflow_base =~ s/\A(.*)\/t/$1/;
+  }
 
     my $path = catdir( cwd(), 'db' );
     unless( -d $path ) {
